pub enum Error {
MessagePackError,
NoHttpClient,
RequestError(Error),
InvalidUri(String),
Other(String),
}The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Wrap type for errors from opentelemetry datadog exporter
Variants
MessagePackError
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Message pack error
NoHttpClient
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
No http client founded. User should provide one or enable features
RequestError(Error)
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Http requests failed with following errors
InvalidUri(String)
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
The Uri was invalid
Other(String)
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Other errors