#[non_exhaustive]pub struct ModelConfig {
pub service_name: String,
}๐Deprecated since 0.21.0:
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.
Helper struct to custom the mapping between Opentelemetry spans and datadog spans.
This struct will be passed to FieldMappingFn
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_name: String๐Deprecated since 0.21.0:
The opentelemetry-datadog crate is deprecated and will be removed from opentelemetry-rust-contrib. Use https://github.com/DataDog/dd-trace-rs instead. See https://github.com/open-telemetry/opentelemetry-rust-contrib/issues/609 for context.